Scalable Reconstruction Framework - Not Enough Functions
========================================================

SRF-NEF (NEF in short) is a light weight computing application framework in reconstruction of PET
and CT. It is designed to make it easier to deal with complex and time-consuming reconstructing
projects. We wish it could be one of the golden standard in Medical Imaging domain. It is one of
the base projects of imaging process of Tech-Pi_ company.

.. _Tech-Pi: https://www.tech-pi.com/
  
  
Install
-------

Install and update using `pip _`:

.. code-block:: text

    pip install -r srfnef


Documentation
-------------

More details can be found in document.


Donate
------

Minghao develops and supports SRF-NEF and the libraries it uses. In order to grow the community
of contributors and users, and allow the maintainers to devote more time to the projects, `please
donate today`_.

.. _`please donate today`: Alipay - 13681999299
